@@ -1,8 +1,9 @@
 import time
 from pathlib import Path
-from subprocess import PIPE, run
+from subprocess import run
+from typing import Optional
 
-from lamin_logger import logger
+from lamin_utils import logger
 
 
 def setup_local_test_sqlite_file(src_settings, return_dir: bool = False):
@@ -19,10 +20,14 @@ def setup_local_test_sqlite_file(src_settings, return_dir: bool = False):
     return tgt_db
 
 
-def setup_local_test_postgres(name: str = "pgtest"):
+def setup_local_test_postgres(name: str = "pgtest", version: Optional[str] = None):
+    if version is not None:
+        version = ":{version}"
+    else:
+        version = ""
     process = run(
         f"docker run --name {name} -e POSTGRES_PASSWORD=pwd"
-        f" -e POSTGRES_DB={name} -d -p 5432:5432 postgres",  # noqa
+        f" -e POSTGRES_DB={name} -d -p 5432:5432 postgres{version}",  # noqa
         shell=True,
     )
     if process.returncode == 0:
@@ -32,22 +37,9 @@ def setup_local_test_postgres(name: str = "pgtest"):
             f" container '{name}'"
         )
     else:
-        raise RuntimeError("Failed to set up postgres test instance.")
+        raise RuntimeError(
+            "Failed to set up postgres test instance. Try running\n"
+            f"docker stop {name} && docker rm {name}"
+        )
     time.sleep(2)
     return f"postgresql://postgres:pwd@0.0.0.0:5432/{name}"
-
-
-def setup_local_test_postgres_supabase():
-    process = run(
-        f"""supabase start | grep 'anon key'|cut -f2 -d ":" | sed -e 's/^[[:space:]]*//'""",  # noqa
-        shell=True,
-        stdout=PIPE,
-    )
-    anon_key = process.stdout.decode("UTF-8").replace("\n", "")
-    open(".supabase_local_anon_key", "w").write(anon_key)
-    if process.returncode == 0:
-        logger.info("Created Supabase test instance.")
-    else:
-        raise RuntimeError("Failed to set up Supabase test instance.")
-    time.sleep(2)
-    return "postgresql://postgres:postgres@localhost:54322/postgres"
