@@ -1,18 +1,18 @@
 import nox
 
-nox.options.reuse_existing_virtualenvs = True
+nox.options.default_venv_backend = "none"
 
 
 @nox.session
 def lint(session: nox.Session) -> None:
-    session.install("pre-commit")
+    session.run(*"pip install pre-commit".split())
     session.run("pre-commit", "install")
     session.run("pre-commit", "run", "--all-files")
 
 
-@nox.session(python=["3.7", "3.8", "3.9", "3.10", "3.11"])
+@nox.session
 def build(session):
-    session.install(".[dev,test]")
+    session.run(*"pip install .[dev]".split())
     session.run(
         "pytest",
         "-s",
